#[repr(transparent)]pub struct Seed(pub u32);Expand description
CRC seed register
Tuple Fields
0: u32Implementations
Sourceimpl Seed
impl Seed
Sourcepub const fn crc_seed(&self) -> u32
pub const fn crc_seed(&self) -> u32
A write access to this register will load CRC seed value to CRC_SUM register with selected bit order and 1’s complement pre-processes. A write access to this register will overrule the CRC calculation in progresses.
Sourcepub const fn set_crc_seed(&mut self, val: u32)
pub const fn set_crc_seed(&mut self, val: u32)
A write access to this register will load CRC seed value to CRC_SUM register with selected bit order and 1’s complement pre-processes. A write access to this register will overrule the CRC calculation in progresses.